Geographical class

Constructors

Geographical({bool? postal_code, required double area, String? region, String? subregion, String? world_region, String? region_code, String? subregion_code, bool? landlocked, required String independent, required LatLng latLng_dms, required LatLng latLng_dec, required LatLng latLng_min, required LatLng latLng_max})

Properties

area → double
land area in km².
final
borders → List<Country>
land borders.
final
continent → List<Continents>
Continents that country lies in.
final
hashCode → int
The hash code for this object.
no setterinherited
independent → String
independent status.
final
landlocked → bool?
landlocked status.
final
latLng_dec → LatLng
coordinate point in decimal form.
final
latLng_dms → LatLng
coordinate point in degrees minutes seconds form.
final
latLng_max → LatLng
maxmum coordinate point in decimal form.
final
latLng_min → LatLng
minmum coordinate point in decimal form.
final
postal_code → bool?
Geographical area postal code
final
region → String?
geographical region.
final
region_code → String?
geographical sub-region numeric code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subregion → String?
geographical sub-region.
final
subregion_code → String?
geographical sub-region numeric code.
final
world_region → String?
geographical world region.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited