Language class

Constructors

Language({required String iso_639_1_alpha2, required String iso_639_2_alpha3, required String family, required String name, String? native, required String wikiUrl, Map<Language, List<String>?>? name_in})

Properties

family → String
Language family
final
hashCode → int
The hash code for this object.
no setterinherited
iso_639_1_alpha2 → String
Iso_639_1_alpha2 language code
final
iso_639_2_alpha3 → String
Iso_639_1_alph32 language code
final
name → String
language name.
final
name_in ↔ Map<Language, List<String>?>?
Set of all available translation names.
getter/setter pair
native ↔ String?
Set of all native translation names.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wikiUrl → String
Relative link to language wikipedia page.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited