Name class

Constructors

Name({required String official, required String common})

Properties

common → String
Common name in english.
final
hashCode → int
The hash code for this object.
no setterinherited
official → String
Official name in english.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited