TimeZone class

Constructors

TimeZone({required String zoneName, required int gmtOffset, required String gmtOffsetName, required String abbreviation, required String tzName})

Properties

abbreviation → String
final
gmtOffset → int
final
gmtOffsetName → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tzName → String
final
zoneName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited